<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xalan="http://xml.apache.org/xalan">

  <xsl:include href="common.xsl"/>

  <xsl:output method="html"/>
  <!-- set mode to cd/web/wiki depending on where the files will end up -->
  <xsl:variable name="mode">cd</xsl:variable>
  
  <xsl:variable name="manifest" select="document('manifest.xml')/Manifest"/>
  <xsl:variable name="tutorial" select="/TutorialList"/>

  <xsl:template match="/">
    <html>
      <head>
	<title><xsl:value-of select="$manifest/Title"/></title>
	<style type="text/css">
	  h1.pagebreak {page-break-before: always}
	</style>
      </head>
      <body>
	<a name="index"/>
	<h1><xsl:value-of select="$manifest/Title"/></h1>
	<xsl:apply-templates select="$manifest/Section" mode="index"/>
	<xsl:apply-templates select="$manifest/Section"/>
	
	<div style="text-align:center;"><xsl:apply-templates select="/TutorialList/SupplementaryText/Text[@id='copyright']"/></div>
	
      </body>
    </html>
  </xsl:template>  
  
  
  <xsl:template match="Section" mode="index">
    <xsl:variable name="secnum" select="@number"/>
    <div style="page-break-after: always;">    
    <h2><a href="#{@id}"><xsl:value-of select="Heading"/></a></h2>
    <xsl:for-each select="TutorialRef|SplitTutorialRef">
      <dl>
	<xsl:variable name="id" select="@id"/>
	<xsl:variable name="pos" select="position()"/>
	<xsl:if test="self::TutorialRef">
	  <xsl:apply-templates select="$tutorial/Tutorial[@id=$id]" mode="index">
	    <xsl:with-param name="number">
              <xsl:value-of select="$pos"/>
              <!--<xsl:value-of select="$secnum"/>.<xsl:value-of select="$pos"/>-->
            </xsl:with-param>
	  </xsl:apply-templates>
	</xsl:if>
	<xsl:if test="self::SplitTutorialRef">
	  <xsl:apply-templates select="$tutorial/Tutorial[@id=$id]" mode="splitindex">
	    <xsl:with-param name="number">
              <xsl:value-of select="$pos"/>
              <!--<xsl:value-of select="$secnum"/>.<xsl:value-of select="$pos"/>-->
            </xsl:with-param>
	    <xsl:with-param name="split" select="@split"/>
	    <xsl:with-param name="type" select="@type"/>
	    <xsl:with-param name="current" select="@current"/>
	    <xsl:with-param name="titleextra" select="@titleextra"/>
	  </xsl:apply-templates>
	</xsl:if>
      </dl>
    </xsl:for-each>
    </div>
  </xsl:template>
  
  <xsl:template match="Section">
    <xsl:variable name="secnum" select="@number"/>
    <a name="{@id}"/>
    <h1 class="pagebreak"><xsl:value-of select="Heading"/></h1>
    <xsl:for-each select="TutorialRef|SplitTutorialRef">
      <xsl:variable name="id" select="@id"/>
      <xsl:variable name="pos" select="position()"/>
      <xsl:if test="self::TutorialRef">
	<xsl:apply-templates select="$tutorial/Tutorial[@id=$id]">
          <xsl:with-param name="number">
            <!-- for just one section -->
            <xsl:value-of select="$pos"/>
            <!-- for more than one sections -->
	   <!--<xsl:value-of select="$secnum"/>.<xsl:value-of select="$pos"/>-->
          </xsl:with-param>
	</xsl:apply-templates>
      </xsl:if>
      <xsl:if test="self::SplitTutorialRef">
	<xsl:apply-templates select="$tutorial/Tutorial[@id=$id]" mode="split">
	  <xsl:with-param name="number">
            <xsl:value-of select="$pos"/>
            <!--<xsl:value-of select="$secnum"/>.<xsl:value-of select="$pos"/>-->
          </xsl:with-param>
	  <xsl:with-param name="split" select="@split"/>
	  <xsl:with-param name="type" select="@type"/>
	  <xsl:with-param name="current" select="@current"/>
	  <xsl:with-param name="titleextra" select="@titleextra"/>
	  <xsl:with-param name="beginnotes" select="BeginNotes"/>
	  <xsl:with-param name="endnotes" select="EndNotes"/>
	</xsl:apply-templates>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  
  <xsl:template match="Tutorial">    
    <xsl:param name="number"/>
    <div style="page-break-after: always;">
    <h2><xsl:value-of select="$number"/>. <xsl:apply-templates select="Title/Text"/></h2>
    <xsl:apply-templates select="Content/*"/>
    </div>
  </xsl:template>

  <xsl:template match="Tutorial" mode="index">
    <xsl:param name="number"/>
    <dt><b><xsl:value-of select="$number"/>. <xsl:apply-templates select="Title/Text"/></b></dt>
    <dd><xsl:for-each select="Content/Heading">
        <xsl:apply-templates/><br/>
      </xsl:for-each>
    </dd>
  </xsl:template>
  
  <xsl:template match="Tutorial" mode="split">
    <xsl:param name="number"/>
    <xsl:param name="split"/>
    <xsl:param name="type"/>
    <xsl:param name="current"/>
    <xsl:param name="titleextra"/>
    <xsl:param name="beginnotes"/>
    <xsl:param name="endnotes"/>
    
    <div style="page-break-after: always;">
    <h2><xsl:value-of select="$number"/>. <xsl:apply-templates select="Title/Text"/><xsl:value-of select="$titleextra"/></h2>
    <xsl:apply-templates select="$beginnotes"/>
      <xsl:variable name="splitnode" select="xalan:evaluate(concat('Content/',$split))"/>
    <xsl:if test="$type='preceding'">
      <xsl:for-each select="$splitnode">
	<xsl:apply-templates select="preceding-sibling::node()"/>
      </xsl:for-each>
    </xsl:if>
    <xsl:if test="$current='true'">
      <xsl:apply-templates select="$splitnode"/>
    </xsl:if>
    <xsl:if test="$type='following'">
      <xsl:for-each select="$splitnode">
	<xsl:apply-templates select="following-sibling::node()"/>
      </xsl:for-each>
    </xsl:if>
    <xsl:apply-templates select="$endnotes"/>
    </div>
  </xsl:template>

  <xsl:template match="Tutorial" mode="splitindex">
    <xsl:param name="number"/>
    <xsl:param name="split"/>
    <xsl:param name="type"/>
    <xsl:param name="current"/>
    <xsl:param name="titleextra"/>
    
    <dt><b><xsl:value-of select="$number"/>. <xsl:apply-templates select="Title/Text"/><xsl:value-of select="$titleextra"/></b></dt>
    <dd>
      <xsl:variable name="splitnode" select="xalan:evaluate(concat('Content/',$split))"/>
    <xsl:if test="$type='preceding'">
      <xsl:for-each select="$splitnode">
	  <xsl:for-each select="preceding-sibling::Heading">
	    <xsl:apply-templates/><br/>
	  </xsl:for-each>
	</xsl:for-each>
      </xsl:if>
      <xsl:if test="$current='true'">
	<xsl:for-each select="$splitnode">
	  <xsl:apply-templates/><br/>
	</xsl:for-each>
      </xsl:if>
      <xsl:if test="$type='following'">
	<xsl:for-each select="$splitnode">
	  <xsl:for-each select="following-sibling::Heading">
	    <xsl:apply-templates/><br/>
	  </xsl:for-each>
	</xsl:for-each>
      </xsl:if>
    </dd>
  </xsl:template>

  <xsl:template match="TutorialRef" priority="2">
    <xsl:variable name="ref" select="@id"/>
    <b><xsl:value-of select="/TutorialList/Tutorial[@id=$ref]/Title/Text"/></b>
  </xsl:template>

</xsl:stylesheet>
